'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var ramda = require('ramda');
var ramdaExtension = require('ramda-extension');
var React = _interopDefault(require('react'));

/**
 * Returns the display name of a React component, falling back appropriately.
 *
 * @param {React.Component} Component React component to get the name of
 * @returns {string}
 */

var getDisplayName = ramdaExtension.dispatch([ramda.prop('displayName'), ramda.prop('name'), ramda.unless(ramda.both(ramdaExtension.isString, ramdaExtension.isNotEmpty), ramda.always('Component'))]);

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

var withProps = ramda.curry(function (otherProps, NextComponent) {
  var WithProps = function WithProps(props) {
    return React.createElement(NextComponent, _extends({}, props, ramdaExtension.isFunction(otherProps) ? otherProps(props) : otherProps));
  };

  WithProps.displayName = "WithProps(" + getDisplayName(NextComponent) + ")";
  return WithProps;
});

exports.getDisplayName = getDisplayName;
exports.withProps = withProps;
